@@ -208,6 +208,9 @@ class Controller(object):
                 elif event.action == "6":  # variable change
                     self.variable_container.websocket_event(event)
 
+            elif event.control == "_3":  # node change
+                print ("NODE CHANGE {}".format(event))
+
             elif event.control == "_5":  # system status
                 self.process_system_status(event)
 
